var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { EVMContractAddress, ONFT721RewardContractError, } from "@snickerdoodlelabs/objects";
import { injectable } from "inversify";
import { ResultAsync, okAsync, errAsync } from "neverthrow";
import { ResultUtils } from "neverthrow-result-utils";
import { ERC7529Contract } from "../implementations/ERC7529Contract.js";
import { ERewardRoles } from "../interfaces/enums/ERewardRoles.js";
import { ContractsAbis } from "../interfaces/objects/index.js";
let ONFT721RewardContract = class ONFT721RewardContract extends ERC7529Contract {
    constructor(providerOrSigner, contractAddress) {
        super(providerOrSigner, contractAddress, ContractsAbis.ONFT721Reward.abi);
        this.providerOrSigner = providerOrSigner;
        this.contractAddress = contractAddress;
        this.filters = {
            Transfer: (fromAddress, toAddress) => {
                return this.contract.filters.Transfer(fromAddress, toAddress);
            },
        };
    }
    getContractAddress() {
        return this.contractAddress;
    }
    getOwner() {
        return ResultAsync.fromPromise(this.contract.getRoleMember(ERewardRoles.DEFAULT_ADMIN_ROLE, 0), (e) => {
            return this.generateError(e, "Unable to call getRoleMember()");
        });
    }
    // Returns an array of address that has the DEFAULT_ADMIN_ROLE on the Reward contract
    // Note that the address on index 0 is the contract owner
    getDefaultAdminRoleMembers() {
        return ResultAsync.fromPromise(this.contract.getRoleMemberCount(ERewardRoles.DEFAULT_ADMIN_ROLE), (e) => {
            return this.generateError(e, "Unable to call getDefaultAdminRoleMembers()");
        }).andThen((memberCount) => {
            // First get an array of index values so that it can be used with ResultUtils.combine
            const memberIndexArray = [];
            for (let i = 0n; i < memberCount; i++) {
                memberIndexArray.push(i);
            }
            // Map through each index value and get its role member address
            return ResultUtils.combine(memberIndexArray.map((index) => {
                return ResultAsync.fromPromise(this.contract.getRoleMember(ERewardRoles.DEFAULT_ADMIN_ROLE, index), (e) => {
                    return this.generateError(e, "Unable to call getRoleMember()");
                });
            }));
        });
    }
    getMinterRoleMembers() {
        return ResultAsync.fromPromise(this.contract.getRoleMemberCount(ERewardRoles.MINTER_ROLE), (e) => {
            return this.generateError(e, "Unable to call getSignerRoleMembers()");
        }).andThen((memberCount) => {
            // First get an array of index values so that it can be used with ResultUtils.combine
            const memberIndexArray = [];
            for (let i = 0n; i < memberCount; i++) {
                memberIndexArray.push(i);
            }
            // Map through each index value and get its role member address
            return ResultUtils.combine(memberIndexArray.map((index) => {
                return ResultAsync.fromPromise(this.contract.getRoleMember(ERewardRoles.MINTER_ROLE, index), (e) => {
                    return this.generateError(e, "Unable to call getRoleMember() for MINTER_ROLE");
                });
            }));
        });
    }
    baseURI() {
        return ResultAsync.fromPromise(this.contract.baseURI(), (e) => {
            return this.generateError(e, "Unable to call baseURI()");
        });
    }
    setBaseURI(baseUri, overrides) {
        return this.writeToContract("setBaseURI", [baseUri], overrides);
    }
    balanceOf(address) {
        return ResultAsync.fromPromise(this.contract.balanceOf(address), (e) => {
            return this.generateError(e, "Unable to call balanceOf()");
        }).map((numberOfTokens) => {
            // TODO: Not sure if we can always be sure that numberOfTokens is a valid number, but seems reasonable
            return Number(numberOfTokens);
        });
    }
    // NOTE: If a given token id does not exist, the read transaction will revert.
    ownerOf(tokenId) {
        return ResultAsync.fromPromise(this.contract.ownerOf(tokenId), (e) => {
            return this.generateError(e, "Unable to call ownerOf()");
        });
    }
    tokenURI(tokenId) {
        return ResultAsync.fromPromise(this.contract.tokenURI(tokenId), (e) => {
            return this.generateError(e, "Unable to call tokenURI()");
        }).orElse((error) => {
            // The contract reverts with this message if tokenId does not exist
            if (error.reason ===
                "ONFT721: operator query for nonexistent token") {
                return okAsync(null);
            }
            return errAsync(error);
        });
    }
    hasRole(role, address) {
        return ResultAsync.fromPromise(this.contract.hasRole(ERewardRoles[role], address), (e) => {
            return this.generateError(e, "Unable to call hasRole()");
        });
    }
    grantRole(role, address, overrides) {
        return this.writeToContract("grantRole", [ERewardRoles[role], address], overrides);
    }
    revokeRole(role, address, overrides) {
        return this.writeToContract("revokeRole", [ERewardRoles[role], address], overrides);
    }
    renounceRole(role, address, overrides) {
        return this.writeToContract("renounceRole", [ERewardRoles[role], address], overrides);
    }
    // ===== Start: Functions to support testing pre-mint NFTs =====
    // ERC1155 contracts also have the same setApproveForAll function
    isApprovedForAll(tokenOwnerAddress, operatorToApprove) {
        return ResultAsync.fromPromise(this.contract.isApprovedForAll(tokenOwnerAddress, operatorToApprove), (e) => {
            return this.generateError(e, "Unable to call isApprovedForAll()");
        });
    }
    // NOTE: To support this, the user would need to connect their external wallet that owns the NFTs to sign the approval txs
    setApproveForAll(addressToApprove, approved, overrides) {
        return this.writeToContract("setApproveForAll", [addressToApprove, approved], overrides);
    }
    // Function that the escrow wallet will call to transfer NFTs from ONFT721 rewards after they are approved
    // Note: Unlike setApproveForAll, ONFT721's ABI for safeTransferFrom only supports ONFT721 as ERC1155's safeTransferFrom function takes additional parameters, refer to:
    // ERC721 : https://docs.openzeppelin.com/contracts/5.x/api/token/erc721#IERC721-safeTransferFrom-address-address-uint256-
    // ERC1155 : https://docs.openzeppelin.com/contracts/5.x/api/token/erc1155#IERC1155-safeTransferFrom-address-address-uint256-uint256-bytes-
    safeTransferFrom(from, to, tokenId, overrides) {
        return this.writeToContract("safeTransferFrom", [from, to, tokenId], overrides);
    }
    // ===== End: Functions to support pre-mint NFTs =====
    // TODO: Add Layer Zero cross chain functions when needed.
    generateContractSpecificError(msg, e, transaction) {
        return new ONFT721RewardContractError(msg, e, transaction);
    }
};
ONFT721RewardContract = __decorate([
    injectable(),
    __metadata("design:paramtypes", [Object, String])
], ONFT721RewardContract);
export { ONFT721RewardContract };
//# sourceMappingURL=ONFT721RewardContract.js.map