var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { EVMContractAddress, OperatorGatewayContractError, InvalidParametersError, } from "@snickerdoodlelabs/objects";
import { injectable } from "inversify";
import { errAsync, ResultAsync } from "neverthrow";
import { ERC7529Contract } from "../implementations/ERC7529Contract.js";
import { P256VerificationData, ContractsAbis, P256KeyStruct, } from "../interfaces/objects/index.js";
let OperatorGatewayContract = class OperatorGatewayContract extends ERC7529Contract {
    constructor(providerOrSigner, contractAddress) {
        super(providerOrSigner, contractAddress, ContractsAbis.OperatorGatewayAbi.abi);
        this.providerOrSigner = providerOrSigner;
        this.contractAddress = contractAddress;
    }
    deployWallets(usernames, keyIds, p256Keys, evmAccounts, overrides) {
        // Create the P256KeyStruct to match the contract params
        const p256KeysStructs = new Array();
        for (let i = 0; i < p256Keys.length; i++) {
            const newP256KeyStruct = new Array();
            for (let j = 0; j < p256Keys[i].length; j++) {
                newP256KeyStruct.push(new P256KeyStruct(p256Keys[i][j].x, p256Keys[i][j].y, keyIds[i][j]));
            }
            p256KeysStructs.push(newP256KeyStruct);
        }
        return this.writeToContract("deployWallets", [usernames, p256KeysStructs, evmAccounts], overrides);
    }
    authorizeWalletsOnDestinationChain(destinationLayerZeroEndpointId, usernames, gas, nativeTokenFee, // Required fee calculated from the quote function to be sent with the transaction to pay for the LayerZero _lzReceive() call
    overrides) {
        // If there are no overrides provided, create an empty object
        const overridesWithFee = overrides ? overrides : {};
        // include the fee in the overrides object
        overridesWithFee.value = nativeTokenFee;
        return this.writeToContract("reserveWalletsOnDestinationChain", [destinationLayerZeroEndpointId, usernames, gas], overrides);
    }
    authorizeOperatorGatewayOnDestinationChain(destinationLayerZeroEndpointId, gas, nativeTokenFee, // Required fee calculated from the quote function to be sent with the transaction to pay for the LayerZero _lzReceive() call
    overrides) {
        // If there are no overrides provided, create an empty object
        const overridesWithFee = overrides ? overrides : {};
        // include the fee in the overrides object
        overridesWithFee.value = nativeTokenFee;
        return this.writeToContract("authorizeOperatorGatewayOnDestinationChain", [destinationLayerZeroEndpointId, gas], overrides);
    }
    quoteAuthorizeWalletOnDestinationChain(destinationLayerZeroEndpointId, username, gas) {
        return ResultAsync.fromPromise(this.contract.quoteAuthorizeWalletOnDestinationChain(destinationLayerZeroEndpointId, username, gas), (e) => {
            return this.generateError(e, "Unable to call quoteAuthorizeWalletOnDestinationChain()");
        }).map((quotedFee) => {
            // The quoted fee is returned as fee in [native token, layer zero token]
            // We only need the native token fee amount
            return quotedFee[0];
        });
    }
    quoteAuthorizeOperatorGatewayOnDestinationChain(destinationLayerZeroEndpointId, domain, gas) {
        return ResultAsync.fromPromise(this.contract.quoteAuthorizeOperatorGatewayOnDestinationChain(destinationLayerZeroEndpointId, domain, gas), (e) => {
            return this.generateError(e, "Unable to call quoteAuthorizeOperatorGatewayOnDestinationChain()");
        }).map((quotedFee) => {
            // The quoted fee is returned as fee in [native token, layer zero token]
            // We only need the native token fee amount
            return quotedFee[0];
        });
    }
    addP256KeysWithP256Keys(evmAccounts, keyIds, authenticatorDatas, clientJSONDatas, newP256KeyIds, newP256Keys, p256Signatures, overrides) {
        const verificationDatas = new Array();
        if (authenticatorDatas.length !== clientJSONDatas.length) {
            return errAsync(new InvalidParametersError("authenticatorDatas and clientJSONDatas must be the same length"));
        }
        for (let i = 0; i < authenticatorDatas.length; i++) {
            verificationDatas.push(new P256VerificationData(authenticatorDatas[i], clientJSONDatas[i].clientDataJSONLeft, clientJSONDatas[i].clientDataJSONRight));
        }
        // Create the P256KeyStruct to match the contract params
        const newP256KeyStructs = new Array();
        for (let i = 0; i < newP256Keys.length; i++) {
            newP256KeyStructs.push(new P256KeyStruct(newP256Keys[i].x, newP256Keys[i].y, newP256KeyIds[i]));
        }
        return this.writeToContract("addP256KeyWithP256Key", [
            evmAccounts,
            keyIds,
            verificationDatas,
            newP256KeyStructs,
            p256Signatures,
        ], overrides);
    }
    grantRole(role, address, overrides) {
        return this.writeToContract("grantRole", [role, address], overrides);
    }
    revokeRole(role, address, overrides) {
        return this.writeToContract("revokeRole", [role, address], overrides);
    }
    renounceRole(role, address, overrides) {
        return this.writeToContract("renounceRole", [role, address], overrides);
    }
    hasRole(role, address) {
        return ResultAsync.fromPromise(this.contract.hasRole(role, address), (e) => {
            return this.generateError(e, "Unable to call hasRole()");
        });
    }
    computeWalletAddresses(userNames) {
        return ResultAsync.fromPromise(this.contract.computeWalletAddresses(userNames), (e) => {
            return this.generateError(e, "Unable to call getFactory()");
        });
    }
    factoryAddress() {
        return ResultAsync.fromPromise(this.contract.getFactory(), (e) => {
            return this.generateError(e, "Unable to call getFactory()");
        });
    }
    domainName() {
        return ResultAsync.fromPromise(this.contract.getDomainName(), (e) => {
            return this.generateError(e, "Unable to call getDomainName()");
        });
    }
    generateContractSpecificError(msg, e, transaction) {
        return new OperatorGatewayContractError(msg, e, transaction);
    }
};
OperatorGatewayContract = __decorate([
    injectable(),
    __metadata("design:paramtypes", [Object, String])
], OperatorGatewayContract);
export { OperatorGatewayContract };
//# sourceMappingURL=OperatorGatewayContract.js.map