import { EVMAccountAddress, EVMContractAddress, BlockchainCommonErrors, SnickerdoodleFactoryContractError, LayerZeroEndpointId, TokenAmount, InvalidParametersError, OperatorDomain, SnickerdoodleWalletUsernameWithDomain, SnickerdoodleWalletUsername } from "@snickerdoodlelabs/objects";
import { BytesLike, ethers } from "ethers";
import { ResultAsync } from "neverthrow";
import { BaseContract } from "../implementations/BaseContract.js";
import { IEthersContractError } from "../implementations/BlockchainErrorMapper.js";
import { ContractOverrides, WrappedTransactionResponse, ISnickerdoodleFactoryContract } from "../interfaces/index.js";
import { P256KeyStruct } from "../interfaces/objects/index.js";
export declare class SnickerdoodleWalletFactoryContract extends BaseContract<SnickerdoodleFactoryContractError> implements ISnickerdoodleFactoryContract {
    protected providerOrSigner: ethers.Provider | ethers.Signer;
    protected contractAddress: EVMContractAddress;
    constructor(providerOrSigner: ethers.Provider | ethers.Signer, contractAddress: EVMContractAddress);
    setPeer(layerZeroEndpointId: LayerZeroEndpointId, SnickerdoodleWalletFactoryAddress: EVMContractAddress, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | SnickerdoodleFactoryContractError>;
    peers(destinationChainEid: LayerZeroEndpointId): ResultAsync<EVMContractAddress, SnickerdoodleFactoryContractError | BlockchainCommonErrors | InvalidParametersError>;
    walletBeaconAddress(): ResultAsync<EVMContractAddress, SnickerdoodleFactoryContractError | BlockchainCommonErrors>;
    operatorGatewayBeaconAddress(): ResultAsync<EVMContractAddress, SnickerdoodleFactoryContractError | BlockchainCommonErrors>;
    deployWalletProxies(usernames: SnickerdoodleWalletUsername[], p256Keys: P256KeyStruct[][], evmAccounts: EVMContractAddress[][] | EVMAccountAddress[][], overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | SnickerdoodleFactoryContractError>;
    deployWalletProxy(username: SnickerdoodleWalletUsername, p256Keys: P256KeyStruct[], evmAccounts: EVMContractAddress[] | EVMAccountAddress[], overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | SnickerdoodleFactoryContractError>;
    updateWalletHash(newWalletHash: BytesLike, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | SnickerdoodleFactoryContractError>;
    deployOperatorGatewayProxy(domain: OperatorDomain, adminAccounts: EVMAccountAddress[] | EVMContractAddress[], operatorAccounts: EVMAccountAddress[] | EVMContractAddress[], overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | SnickerdoodleFactoryContractError>;
    authorizeOperatorGatewayOnDestinationChain(destinationLayerZeroEndpointId: LayerZeroEndpointId, domain: OperatorDomain, gas: bigint, nativeTokenFee: bigint, // Required fee calculated from the quoteAuthorizeOperatorGatewayOnDestinationChain function to be sent with the transaction to pay for the LayerZero _lzReceive() call
    overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | SnickerdoodleFactoryContractError>;
    quoteAuthorizeOperatorGatewayOnDestinationChain(destinationLayerZeroEndpointId: LayerZeroEndpointId, domain: OperatorDomain, gas: bigint): ResultAsync<TokenAmount, SnickerdoodleFactoryContractError | BlockchainCommonErrors>;
    computeProxyAddress(salt: SnickerdoodleWalletUsernameWithDomain | OperatorDomain, // The salt used to create the proxy address
    beaconAddress: EVMContractAddress): ResultAsync<EVMContractAddress, SnickerdoodleFactoryContractError | BlockchainCommonErrors>;
    computeWalletAddress(username: SnickerdoodleWalletUsername): ResultAsync<EVMContractAddress, SnickerdoodleFactoryContractError | BlockchainCommonErrors>;
    isSourceChain(): ResultAsync<boolean, SnickerdoodleFactoryContractError | BlockchainCommonErrors>;
    getOperatorDomainName(operatorGatewayAddress: EVMContractAddress): ResultAsync<string, SnickerdoodleFactoryContractError | BlockchainCommonErrors>;
    getWalletHash(walletAddress: EVMContractAddress): ResultAsync<string, SnickerdoodleFactoryContractError | BlockchainCommonErrors>;
    getOperatorHash(operatorGatewayAddress: EVMContractAddress): ResultAsync<string, SnickerdoodleFactoryContractError | BlockchainCommonErrors>;
    protected generateContractSpecificError(msg: string, e: IEthersContractError, transaction: ethers.Transaction | null): SnickerdoodleFactoryContractError;
}
//# sourceMappingURL=SnickerdoodleFactoryContract.d.ts.map