import { EVMAccountAddress, BlockchainCommonErrors, UnixTimestamp, FarcasterKeyGatewayContractError, FarcasterUserId, FarcasterSignedKeyRequestSignature, FarcasterEncodedSignedKeyRequestMetadata, FarcasterKeyGatewayAddKeySignature, ED25519PublicKey } from "@snickerdoodlelabs/objects";
import { TypedDataField, ethers } from "ethers";
import { ResultAsync } from "neverthrow";
import { BaseContract } from "../../implementations/BaseContract.js";
import { IEthersContractError } from "../../implementations/BlockchainErrorMapper.js";
import { ContractOverrides, IFarcasterKeyGatewayContract, WrappedTransactionResponse } from "../../interfaces/index.js";
import { SignedKeyRequest } from "../../interfaces/objects/index.js";
import { FarcasterKeyGatewayAddKeySignatureParams } from "../../interfaces/objects/farcaster/index.js";
export declare class FarcasterKeyGatewayContract extends BaseContract<FarcasterKeyGatewayContractError> implements IFarcasterKeyGatewayContract {
    protected providerOrSigner: ethers.Provider | ethers.Signer;
    constructor(providerOrSigner: ethers.Provider | ethers.Signer);
    nonces(address: EVMAccountAddress): ResultAsync<bigint, FarcasterKeyGatewayContractError | BlockchainCommonErrors>;
    add(keyToAdd: ED25519PublicKey, encodedMetadata: FarcasterEncodedSignedKeyRequestMetadata, // obtained from getEncodedSignedKeyRequestMetadata()
    overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, FarcasterKeyGatewayContractError | BlockchainCommonErrors>;
    addFor(fidOwnerAddress: EVMAccountAddress, keyToAdd: ED25519PublicKey, encodedMetadata: FarcasterEncodedSignedKeyRequestMetadata, deadline: UnixTimestamp, signature: FarcasterKeyGatewayAddKeySignature, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, FarcasterKeyGatewayContractError | BlockchainCommonErrors>;
    getAddSignatureParams(ownerAddress: EVMAccountAddress, keyToAdd: ED25519PublicKey, encodedMetadata: FarcasterEncodedSignedKeyRequestMetadata, deadline: UnixTimestamp): ResultAsync<FarcasterKeyGatewayAddKeySignatureParams, FarcasterKeyGatewayContractError | BlockchainCommonErrors>;
    getAddSignature(ownerAddress: EVMAccountAddress, keyToAdd: ED25519PublicKey, encodedMetadata: FarcasterEncodedSignedKeyRequestMetadata, deadline: UnixTimestamp): ResultAsync<FarcasterKeyGatewayAddKeySignature, FarcasterKeyGatewayContractError | BlockchainCommonErrors>;
    getSignedKeyRequestSignatureAndEncodedMetadata(ownerFid: FarcasterUserId, ownerEVMAddress: EVMAccountAddress, keyToAdd: ED25519PublicKey, deadline: UnixTimestamp): ResultAsync<SignedKeyRequest, FarcasterKeyGatewayContractError | BlockchainCommonErrors>;
    getSignedKeyRequestSignature(ownerFid: FarcasterUserId, keyToAdd: ED25519PublicKey, // key to be tied to account
    deadline: UnixTimestamp): ResultAsync<FarcasterSignedKeyRequestSignature, FarcasterKeyGatewayContractError | BlockchainCommonErrors>;
    protected removeReadonlyFromReadonlyTypes<T>(obj: T): Record<string, TypedDataField[]>;
    protected generateContractSpecificError(msg: string, e: IEthersContractError, transaction: ethers.Transaction | null): FarcasterKeyGatewayContractError;
}
//# sourceMappingURL=FarcasterKeyGatewayContract.d.ts.map